@@ -1,4 +1,4 @@
-/* Copyright (C) 2008-2025 Free Software Foundation, Inc.
+/* Copyright (C) 2008-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -474,7 +474,7 @@ display_one_tib (ptid_t ptid)
       tib_size = FULL_TIB_SIZE;
       max = tib_size / size;
     }
-  
+
   tib = (gdb_byte *) alloca (tib_size);
 
   if (!target_get_tib_address (ptid, &thread_local_base))
@@ -489,7 +489,7 @@ display_one_tib (ptid_t ptid)
     {
       gdb_printf (_("Unable to read thread information "
 		    "block for %s at address %s\n"),
-		  target_pid_to_str (ptid).c_str (), 
+		  target_pid_to_str (ptid).c_str (),
 		  paddress (current_inferior ()->arch (), thread_local_base));
       return -1;
     }
@@ -500,7 +500,7 @@ display_one_tib (ptid_t ptid)
 
   index = (gdb_byte *) tib;
 
-  /* All fields have the size of a pointer, this allows to iterate 
+  /* All fields have the size of a pointer, this allows to iterate
      using the same for loop for both layouts.  */
   for (i = 0; i < max; i++)
     {
@@ -511,8 +511,8 @@ display_one_tib (ptid_t ptid)
 	gdb_printf (_("TIB[0x%s] is 0x%s\n"), phex (i * size, 2),
 		    phex (val, size));
       index += size;
-    } 
-  return 1;  
+    }
+  return 1;
 }
 
 /* Display thread information block of the current thread.  */
@@ -922,10 +922,10 @@ windows_solib_ops::iterate_over_objfiles_in_search_order
 	return;
     }
 
-  for (objfile *objfile : m_pspace->objfiles ())
-    if (objfile != current_objfile)
+  for (objfile &objfile : m_pspace->objfiles ())
+    if (&objfile != current_objfile)
       {
-	if (cb (objfile))
+	if (cb (&objfile))
 	  return;
       }
 }
@@ -1103,11 +1103,9 @@ struct cpms_data
 };
 
 static void
-core_process_module_section (bfd *abfd, asection *sect, void *obj)
+core_process_module_section (bfd *abfd, asection *sect, cpms_data &data)
 {
-  struct cpms_data *data = (struct cpms_data *) obj;
-  enum bfd_endian byte_order = gdbarch_byte_order (data->gdbarch);
-
+  bfd_endian byte_order = gdbarch_byte_order (data.gdbarch);
   unsigned int data_type;
   char *module_name;
   size_t module_name_size;
@@ -1154,10 +1152,10 @@ core_process_module_section (bfd *abfd, asection *sect, void *obj)
   module_name = (char *) buf.data () + module_name_offset;
 
   /* The first module is the .exe itself.  */
-  if (data->module_count != 0)
+  if (data.module_count != 0)
     windows_xfer_shared_library (module_name, base_addr,
-				 NULL, data->gdbarch, data->xml);
-  data->module_count++;
+				 NULL, data.gdbarch, data.xml);
+  data.module_count++;
 }
 
 ULONGEST
@@ -1166,7 +1164,10 @@ windows_core_xfer_shared_libraries (struct gdbarch *gdbarch,
 				    ULONGEST offset, ULONGEST len)
 {
   cpms_data data { gdbarch, "<library-list>\n", 0 };
-  bfd_map_over_sections (&cbfd, core_process_module_section, &data);
+
+  for (asection *sect : gdb_bfd_sections (&cbfd))
+    core_process_module_section (&cbfd, sect, data);
+
   data.xml += "</library-list>\n";
 
   ULONGEST len_avail = data.xml.length ();
@@ -1387,7 +1388,7 @@ cygwin_sigwrapper_frame_unwind::sniff (const frame_info_ptr &this_frame,
 
   frame_debug_printf ("sigstackptroffset=%x", tlsoffset);
 
-  auto *cache = FRAME_OBSTACK_ZALLOC (struct cygwin_sigwrapper_frame_cache);
+  auto *cache = frame_obstack_zalloc<struct cygwin_sigwrapper_frame_cache> ();
   cache->tlsoffset = tlsoffset;
 
   *this_cache = cache;
